@@ -3,13 +3,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0602';
+our $VERSION = '0.0603';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
-use Music::Scales qw(get_scale_notes);
 use Music::Chord::Note;
+use Music::Scales qw(get_scale_notes);
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -285,7 +285,6 @@ sub _tt_sub {
 }
 
 
-# These gymnastics are performed to appease Music::Chord::Note
 sub substitution {
     my ($self, $chord) = @_;
 
@@ -333,7 +332,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0602
+version 0.0603
 
 =head1 SYNOPSIS
 
@@ -341,23 +340,23 @@ version 0.0602
 
   my $prog = Music::Chord::Progression->new;
 
-  my $chords = $prog->generate;
+  my $chords = $prog->generate; # LoL with "max" number of bars
 
-  my $chord = $prog->substitution('m'); # returns m7 or mM7
+  my $chord_type = $prog->substitution('m'); # returns m7 or mM7
 
 =head1 DESCRIPTION
 
 C<Music::Chord::Progression> creates network transition chord
 progressions.
 
-Also this module can perform limited jazz chord substitutions, if
+This module can also perform limited jazz chord substitutions, if
 requested in the constructor.
 
 =head1 ATTRIBUTES
 
 =head2 max
 
-The maximum number of chords to generate.
+The number of chords to generate in a phrase.
 
 Default: C<8>
 
@@ -375,20 +374,20 @@ Default:
     6 => [qw( 1 2 4 5 )],
     7 => [] }
 
-A chromatic example:
+A contrived chromatic example where each note connects to every note:
 
   { 1  => [1 .. 12],
-    2  => [1 .. 11],
-    3  => [1 .. 10],
-    4  => [1 .. 9],
-    5  => [1 .. 8],
-    6  => [1 .. 7],
-    7  => [1 .. 6],
-    8  => [1 .. 5],
-    9  => [1 .. 4],
-    10 => [1 .. 3],
-    11 => [1 .. 2],
-    12 => [1],
+    2  => [1 .. 12],
+    3  => [1 .. 12],
+    4  => [1 .. 12],
+    5  => [1 .. 12],
+    6  => [1 .. 12],
+    7  => [1 .. 12],
+    8  => [1 .. 12],
+    9  => [1 .. 12],
+    10 => [1 .. 12],
+    11 => [1 .. 12],
+    12 => [1 .. 12],
   }
 
 The keys must start with C<1> and be contiguous to the end.
@@ -404,8 +403,8 @@ in the first example, the 7th degree of the scale will never be chosen.
 
 The chord names of each scale position.
 
-The number of items in this list must be equal and correspond to the
-number of keys in the B<net>.
+The number of items in this list must be equal to the number of keys
+in the B<net>.
 
 Default: C<[ '', 'm', 'm', '', '', 'm', 'dim' ]>
 
@@ -415,7 +414,7 @@ Alternative example:
 
   [ 'M7', 'm7', 'm7', 'M7', '7', 'm7', 'dim7' ]
 
-The different chord names are listed in the source of L<Music::Chord::Note>.
+The known chord names are listed in the source of L<Music::Chord::Note>.
 
 =head2 scale_name
 
@@ -427,7 +426,8 @@ Please see L<Music::Scales/SCALES> for the allowed scale names.
 
 =head2 scale_note
 
-The (uppercase) name of the scale starting note.
+The (uppercase) name of the scale starting note with an optional C<#>
+or C<b> accidental.
 
 Default: C<C>
 
@@ -439,7 +439,7 @@ Default: C<[C D E F G A B]>
 
 =head2 octave
 
-The octave number of the scale.
+The octave of the scale.
 
 Default: C<4>
 
@@ -465,7 +465,7 @@ Default: C<1>
 
 =head2 substitute
 
-Whether to perform jazz chord substitution.
+Perform jazz chord substitution.
 
 Default: C<0>
 
@@ -483,14 +483,13 @@ Rules:
 
 =head2 sub_cond
 
-The subroutine to execute to determine if a chord substitution should
-happen.
+The subroutine to determine if a chord substitution should happen.
 
 Default: C<sub { int rand 4 == 0 }> (25% of the time)
 
 =head2 flat
 
-Whether to use flats instead of sharps in the generated chords or not.
+Use flats instead of sharps in the generated chords.
 
 Default: C<0>
 
@@ -511,7 +510,7 @@ attribute.
 
 =head2 verbose
 
-Show the B<generate> and B<substitution> progress.
+Show the progress and chosen values.
 
 =head1 METHODS
 
@@ -543,9 +542,9 @@ attributes.
 
 =head2 substitution
 
-  $substitute = $prog->substitution($chord_name);
+  $substitute = $prog->substitution($chord_type);
 
-Perform a jazz substitution on the given the named chord.
+Perform a jazz substitution on the given the chord type.
 
 =head1 SEE ALSO
 
